==> hypernet-id-objects-0.0.1.tgz: package/src/IdentityToken.ts <==
import {
	UnixTimestamp,
	CountryCode,
	EthereumAccountAddress,
	BigNumberString,
} from "@hypernetlabs/objects";

export class NewIdentityToken {
	public constructor(
		public ownerAddress: EthereumAccountAddress,
		public timestamp: UnixTimestamp,
		public countryCode: CountryCode,
		public email: boolean,
		public firstName: boolean,
		public lastName: boolean,
		public birthday: boolean,
		public placeOfBirth: boolean,
		public mailingAddress: boolean,
		public residenceAddress: boolean,
		public passport: boolean,
		public drivingLicense: boolean,
		public visa: boolean,
		public nationalId: boolean,
		public consularId: boolean,
		public electoralId: boolean,
		public residentPermitId: boolean,
		public taxId: boolean,
		public studentId: boolean,
		public passportCard: boolean,
		public militaryId: boolean,
		public publicSafetyId: boolean,
		public healthId: boolean,
		public taxEssentials: boolean,
		public socialSecurityNumber: boolean,
		public taxNumber: boolean,
		public naturalPersonsRegister: boolean, // CPF
		public generalRegistrationNumber: boolean,
		public voterIdNumber: boolean,
		public issuingNumber: boolean,
		public gender: boolean,
		public nationality: boolean,
		public livenessImage: boolean,
		public motherName: boolean,
		public fatherName: boolean,
		public verifiedInvestor: boolean,
		public underSanctions: boolean,
		public activeScreening: boolean,
	) {}
}

export class IdentityToken extends NewIdentityToken {
	public constructor(
		public tokenId: BigNumberString,
		ownerAddress: EthereumAccountAddress,
		timestamp: UnixTimestamp,
		countryCode: CountryCode,
		email: boolean,
		firstName: boolean,
		lastName: boolean,
		birthday: boolean,
		placeOfBirth: boolean,
		mailingAddress: boolean,
		residenceAddress: boolean,
		passport: boolean,
		drivingLicense: boolean,
		visa: boolean,
		nationalId: boolean,
		consularId: boolean,
		electoralId: boolean,
		residentPermitId: boolean,
		taxId: boolean,
		studentId: boolean,
		passportCard: boolean,
		militaryId: boolean,
		publicSafetyId: boolean,
		healthId: boolean,
		taxEssentials: boolean,
		socialSecurityNumber: boolean,
		taxNumber: boolean,
		naturalPersonsRegister: boolean, // CPF
		generalRegistrationNumber: boolean,
		voterIdNumber: boolean,
		issuingNumber: boolean,
		gender: boolean,
		nationality: boolean,
		livenessImage: boolean,
		motherName: boolean,
		fatherName: boolean,
		verifiedInvestor: boolean,
		underSanctions: boolean,
		activeScreening: boolean,
	) {
		super(
			ownerAddress,
			timestamp,
			countryCode,
			email,
			firstName,
			lastName,
			birthday,
			placeOfBirth,
			mailingAddress,
			residenceAddress,
			passport,
			drivingLicense,
			visa,
			nationalId,
			consularId,
			electoralId,
			residentPermitId,
			taxId,
			studentId,
			passportCard,
			militaryId,
			publicSafetyId,
			healthId,
			taxEssentials,
			socialSecurityNumber,
			taxNumber,
			naturalPersonsRegister,
			generalRegistrationNumber,
			voterIdNumber,
			issuingNumber,
			gender,
			nationality,
			livenessImage,
			motherName,
			fatherName,
			verifiedInvestor,
			underSanctions,
			activeScreening,
		);
	}
}

==> hypernet-id-objects-0.0.3.tgz: package/src/IdentityToken.ts <==
import {
	UnixTimestamp,
	CountryCode,
	EthereumAccountAddress,
} from "@hypernetlabs/objects";

import { IdentityMetadata } from "@objects/IdentityMetadata";

export class IdentityToken extends IdentityMetadata {
	public constructor(
		public ownerAddress: EthereumAccountAddress,
		timestamp: UnixTimestamp,
		countryCode: CountryCode,
		email: boolean,
		firstName: boolean,
		lastName: boolean,
		birthday: boolean,
		placeOfBirth: boolean,
		mailingAddress: boolean,
		residenceAddress: boolean,
		passport: boolean,
		drivingLicense: boolean,
		visa: boolean,
		nationalId: boolean,
		consularId: boolean,
		electoralId: boolean,
		residentPermitId: boolean,
		taxId: boolean,
		studentId: boolean,
		passportCard: boolean,
		militaryId: boolean,
		publicSafetyId: boolean,
		healthId: boolean,
		taxEssentials: boolean,
		socialSecurityNumber: boolean,
		taxNumber: boolean,
		naturalPersonsRegister: boolean, // CPF
		generalRegistrationNumber: boolean,
		voterIdNumber: boolean,
		issuingNumber: boolean,
		gender: boolean,
		nationality: boolean,
		livenessImage: boolean,
		motherName: boolean,
		fatherName: boolean,
		verifiedInvestor: boolean,
		underSanctions: boolean,
		activeScreening: boolean,
	) {
		super(
			timestamp,
			countryCode,
			email,
			firstName,
			lastName,
			birthday,
			placeOfBirth,
			mailingAddress,
			residenceAddress,
			passport,
			drivingLicense,
			visa,
			nationalId,
			consularId,
			electoralId,
			residentPermitId,
			taxId,
			studentId,
			passportCard,
			militaryId,
			publicSafetyId,
			healthId,
			taxEssentials,
			socialSecurityNumber,
			taxNumber,
			naturalPersonsRegister,
			generalRegistrationNumber,
			voterIdNumber,
			issuingNumber,
			gender,
			nationality,
			livenessImage,
			motherName,
			fatherName,
			verifiedInvestor,
			underSanctions,
			activeScreening,
		);
	}
}
